@@ -43,31 +43,39 @@ void cheese_print_handler(char *string)
   static FILE *fp = NULL;
   GDir *dir;
   char *filename, *path;
+  
+  CheeseFileUtil *fileutil = cheese_fileutil_new ();
+  
 
   if (fp == NULL)
   {
-    path = cheese_fileutil_get_path ();
+    path = cheese_fileutil_get_log_path (fileutil);
+    
     dir = g_dir_open (path, 0, NULL);
-    if (!dir)
+    if (!dir) {
       return;
-
+    }
+    
     filename = g_build_filename (path, "log", NULL);
-    fp = fopen(filename, "w");
+    fp = fopen (filename, "w");
 
-    g_free(filename);
+    g_object_unref (fileutil);
+    g_free (filename);
   }
 
   if (fp)
-    fputs(string, fp);
+    fputs (string, fp);
 
   if (CheeseOptions.verbose)
     fprintf (stdout, "%s", string);
+    
 }
 
 int
 main (int argc, char **argv)
 {
   GOptionContext *context;
+  
   GOptionEntry options[] = {
     { "verbose", 'v', 0, G_OPTION_ARG_NONE, &CheeseOptions.verbose, _("Be verbose"), NULL},
     { "hal-device", 'd', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &CheeseOptions.hal_device_id, NULL, NULL},
@@ -84,7 +92,7 @@ main (int argc, char **argv)
 
   g_set_application_name (_("Cheese"));
 
-  context = g_option_context_new (N_("- Take photos and videos from your webcam"));
+  context = g_option_context_new (N_("- Take photos and videos with your webcam, with fun graphical effects"));
   g_option_context_add_main_entries(context, options, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
   g_option_context_add_group (context, gst_init_get_option_group ());
@@ -93,13 +101,17 @@ main (int argc, char **argv)
 
   gtk_init (&argc, &argv);
   gst_init (&argc, &argv);
+
+  /* Needed for gnome_thumbnail functions */
   gnome_vfs_init ();
 
   g_set_print_handler ((GPrintFunc) cheese_print_handler);
 
   gtk_window_set_default_icon_name ("cheese");
+  gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+                                     APPNAME_DATA_DIR G_DIR_SEPARATOR_S "icons");
 
-  cheese_window_init ();
+  cheese_window_init (CheeseOptions.hal_device_id);
   
   gdk_threads_enter ();
   gtk_main ();
